# Maps and weather data

Persefone.jl requires three map input files: one for land cover, one for
for field geometries, and one for soil types. Additionally, a weather input 
file is needed. This documents describe how to obtain and process the data 
needed for each of these.

There is a QGIS project file at `data/regions/auxiliary/persefone.qgz`, which
can be used get an overview of the existing region input files and add new ones.
All region data files are stored using the following convention:

```
data/regions/<regionname>/
-> <regionname>.geojson
-> landcover.tif
-> fields.tif
-> soil.tif
-> weather.csv
```

Where `<regionname>` is currently one of `bodensee`, `eichsfeld`, `hohenlohe`, `jena`,
`oberrhein`, or `thueringer_becken`.

## Land cover maps

Land cover maps for Germany at 10m resolution can be obtained from 
[Mundialis](https://data.mundialis.de/geonetwork/srv/eng/catalog.search#/metadata/9246503f-6adf-460b-a31e-73a649182d07).
These are generated annually from Sentinel data and comprise the following 
land cover classes:

```
10: forest
20: low vegetation
30: water
40: built-up
50: bare soil
60: agriculture
```

To create a Persefone map input file, you need to crop the national Mundialis
map to the extent that you want to simulate (suggestion: edge lengths between 10-20 km
are a reasonable size).

To do so, download the Mundialis map and import it into QGIS. Then create a new
vector layer and create a rectangle feature to delimit the extent of your
region. You can save this as a GEOJSON file to the region folder for future reference. 
Then go to `Raster -> Extraction -> Clip Raster by Extent`. Select
the Mundialis map as the input layer, set the clipping extent by choosing your
region vector layer under `Calculate from Layer` and specify the output
file name before clicking `Run`. This will generate a TIF file that you can
pass to Persefone as the `landcovermap` parameter.

## Field ID maps

In addition to the land cover data explained above, Persefone also needs
information about agricultural field boundaries in order to assign these to the
farming agents. Unfortunately, getting this is rather more complicated.

In the EU, every country runs a Land Parcel Information System (LPIS) to
administer CAP payments. In Germany, this is called InVeKoS and is run by the
Länder. For example, you can view and download the InVeKoS data for 
[Thüringen](https://thueringenviewer.thueringen.de/thviewer/invekos.html) or
[Baden-Württemberg](https://metadaten.geoportal-bw.de/geonetwork/srv/eng/catalog.search#/metadata/03873032-80e7-41ec-bb3e-3d34231617e4).
This gives you a vector layer which can be loaded into QGIS. However, it needs
to be converted to a raster layer and cropped to your region extent before it
can be used in Persefone.

The first thing to do is to make sure that the vector layer has a numeric (!)
field with a unique identifier for each field block (check the attribute table). 
The Thüringen data has the FBI ("Feldblockident") field, but this is a string
value and therefore not usable by the rasteriser. So, we set the vector layer to
edit mode, open the field calculator, enter the information for a new field 
(call it "FID" and set it to a 32-bit integer), and enter `@row_number` in the 
expression field. Then save the layer and close the calculator.

Secondly, you need to filter out all non-field/non-grassland plot types. (LPIS
also has data on forests and various landscape elements that are not relevant to
our use case.) Assuming you're working with the Thüringen InVeKoS data (other
data sets may have a different structure), right-click on the layer name in
QGIS' layer overview and click on "Filter...". Then, enter this expression in
the query builder: `"BNK" = 'AL' OR "BNK" = 'GL'` and click "OK". This
will select only field and grassland plots.

Next, open the rasteriser (`Raster -> Conversion -> Rasterize`). Select your
FID field as the "Field to use for a burn-in value", and your land cover map (as
created above - this ensures the two layers match) as the output extent. Make sure 
the "fixed value to burn" is "Not set". Then choose "Georeferenced units" as the 
"Out raster size units" and set horizontal and vertical resolution to 10.0. In 
the advanced parameters, set the output data type to `UInt32`. Finally, enter an 
output file name and run. The resulting TIF file can be passed to Persefone
as the `farmfieldmap` parameter.

## Soil data

Soil data for Germany is provided by the Bundesanstalt für Geowissenschaften und
Rohstoffe in form of the [Bodenatlas](https://bodenatlas.bgr.de/). This provides
a (coarse, but for our purposes sufficient) map of the distribution of the basic
soil types such as clay, silt, sand, and loam.

To create the Persefone input file, you first need to rasterise the data. See the
instructions above - choose `BODENART` as the field for the burn-in value. (Note:
rastering the whole map produces a 20GB file! This can later be deleted again.)
Then you need to align and crop it to the extent you require, using the dialog at 
`Raster -> Align Rasters...`. Select your landcover map as the reference layer
and the extent layer, then choose your national soil map as the input. (Don't forget
to define the output file name using `Configure Raster...`, this is a bit hidden.)
The created output file can then be used for the `soilmap` parameter. Its integer
values map onto the `SoilType` enum as follows:

```
1: Abbauflächen -> nosoil
2: Gewässer -> nosoil
3: Lehmsande (ls) -> loamy_sand
4: Lehmschluffe (lu) -> silt_loam
5: Moore -> nosoil
6: Normallehme (ll) -> loam
7: Reinsande (ss) -> sand
8: Sandlehme (sl) -> sandy_loam
9: Schluffsande (us) -> sandy_loam
10: Schlufftone (ut) -> silty_clay
11: Siedlung -> nosoil
12: Tonlehme (tl) -> clay_loam
13: Tonschluffe (tu) -> silty_clay_loam
14: Watt -> nosoil
```

![Soil types triangle](assets/soil_types_english.png)

*Names of soil types are based on the relative composition of clay, silt, and sand.
Note that the typology used in the Bodenatlas does not map perfectly on to this
international classification. Image source: [Australian Environmental Education](https://www.australianenvironmentaleducation.com.au/education-resources/what-is-soil/)*

## Weather data

Currently, Persefone uses historical weather data from the closest weather station
as its weather input. (In future, this may be changed to a more detailed raster
input, which could then also provide future weather predictions under climate change.)
Weather data can be downloaded from the [German weather service (DWD)](https://www.dwd.de/DE/leistungen/cdc/cdc_ueberblick-klimadaten.html?nn=16102).

The description of these data sets and the list of weather stations can be found in the
Persefone repository, in the `docs` folder (or downloaded from the link above).
Using the list of weather stations, select the one closest to the area of study.
Note that not all stations were continuously in operation; make sure that the selected
station covers the years of interest. The currently included regions have the following
station codes:

- **Region Jena:** station number 02444 ("Jena (Sternwarte)")
- **Region Eichsfeld:** station number 02925 ("Leinefelde") 
- **Region Thüringer Becken:** station number 00896 ("Dachwig")
- **Region Hohenlohe:** station number 03761 ("Oehringen")
- **Region Bodensee:** station number 06263 ("Singen")
- **Region Nördlicher Oberrhein:** station number 05275 ("Waghäusel-Kirrlach")

The script `data/regions/auxiliary/extract_weather_data.R` can be used to download
and process the data into the format needed by Persefone. This uses the
[`rdwd`](https://bookdown.org/brry/rdwd/) package. To use it, simply specify the 
desired `region`, adding its ID to the `stationid` list if necessary. The produced
CSV file can be copied into the respective region folder.
